@@ -1,4 +1,9 @@
-## Copyright (C) 2016-2019 Carnë Draug <carandraug+dev@gmail.com>
+########################################################################
+##
+## Copyright (C) 2016-2025 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,12 +20,19 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
-## Private function the functions that convert between color spaces, i.e.,
-## rgb2ntsc, rgb2hsv, hsv2rgb, and ntsc2rgb.  This reverts a colormap type
-## into the same shape and class as it was in the input.  The flags are meant
-## to come from complementary private function
-## colorspace_conversion_input_check()
+## -*- texinfo -*-
+## @deftypefn {} {@var{rv} =} colorspace_conversion_revert (@var{rv}, @var{sz}, @var{is_im}, @var{is_nd})
+##
+## Private function that converts between color spaces.
+##
+## This reverts a colormap type into the same shape and class as it was in the
+## input.  The flags are meant to come from complementary private function
+## @code{colorspace_conversion_input_check}.
+## @seealso{hsv2rgb, rgb2grap, rgb2hsv, colorspace_conversion_input_check}
+## @end deftypefn
 
 function rv = colorspace_conversion_revert (rv, sz, is_im, is_nd)
 
