@@ -1,5 +1,9 @@
-## Copyright (C) 2004-2019 David Bateman
-## Copyright (C) 2009 VZLU Prague
+########################################################################
+##
+## Copyright (C) 2004-2025 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,15 +20,17 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} flipdim (@var{x})
-## @deftypefnx {} {} flipdim (@var{x}, @var{dim})
+## @deftypefn  {} {@var{B} =} flipdim (@var{A})
+## @deftypefnx {} {@var{B} =} flipdim (@var{A}, @var{dim})
 ## This function is obsolete.  Use @code{flip} instead.
 ## @seealso{flip, fliplr, flipud, rot90, rotdim}
 ## @end deftypefn
 
-function y = flipdim (varargin)
+function B = flipdim (varargin)
 
   persistent warned = false;
   if (! warned)
@@ -33,5 +39,6 @@ function y = flipdim (varargin)
              "flipdim is obsolete; please use flip instead");
   endif
 
-  y = flip (varargin{:});
+  B = flip (varargin{:});
+
 endfunction
