@@ -1,4 +1,9 @@
-## Copyright (C) 1994-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1994-2025 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,9 +20,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} roots (@var{c})
+## @deftypefn {} {@var{r} =} roots (@var{c})
 ##
 ## Compute the roots of the polynomial @var{c}.
 ##
@@ -75,13 +82,9 @@
 ## @seealso{poly, compan, fzero}
 ## @end deftypefn
 
-## Author: KH <Kurt.Hornik@wu-wien.ac.at>
-## Created: 24 December 1993
-## Adapted-By: jwe
-
 function r = roots (c)
 
-  if (nargin != 1 || (! isvector (c) && ! isempty (c)))
+  if (nargin < 1 || (! isvector (c) && ! isempty (c)))
     print_usage ();
   elseif (any (! isfinite (c)))
     error ("roots: inputs must not contain Inf or NaN");
@@ -132,8 +135,7 @@ endfunction
 %!assert (roots ([1e-200, -1e200, 1]), 1e-200)
 %!assert (roots ([1e-200, -1e200 * 1i, 1]), -1e-200 * 1i)
 
-%!error roots ()
-%!error roots (1,2)
+%!error <Invalid call> roots ()
 %!error roots ([1, 2; 3, 4])
 %!error <inputs must not contain Inf or NaN> roots ([1 Inf 1])
 %!error <inputs must not contain Inf or NaN> roots ([1 NaN 1])
