@@ -1,4 +1,9 @@
-## Copyright (C) 1996-2019 Daniel Calvelo
+########################################################################
+##
+## Copyright (C) 1996-2025 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,11 +20,13 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} hex2dec (@var{s})
+## @deftypefn {} {@var{d} =} hex2dec (@var{str})
 ## Return the integer corresponding to the hexadecimal number represented by
-## the string @var{s}.
+## the string @var{str}.
 ##
 ## For example:
 ##
@@ -32,25 +39,22 @@
 ## @end group
 ## @end example
 ##
-## If @var{s} is a string matrix, return a column vector with one converted
-## number per row of @var{s}; Invalid rows evaluate to NaN@.
+## If @var{str} is a string matrix, return a column vector with one converted
+## number per row of @var{str}; Invalid rows evaluate to NaN@.
 ##
-## If @var{s} is a cell array of strings, return a column vector with one
-## converted number per cell element in @var{s}.
+## If @var{str} is a cell array of strings, return a column vector with one
+## converted number per cell element in @var{str}.
 ##
 ## @seealso{dec2hex, base2dec, bin2dec}
 ## @end deftypefn
 
-## Author: Daniel Calvelo <dcalvelo@yahoo.com>
-## Adapted-by: Paul Kienzle <pkienzle@kienzle.powernet.co.uk>
-
-function d = hex2dec (s)
+function d = hex2dec (str)
 
   if (nargin != 1)
     print_usage ();
   endif
 
-  d = base2dec (s, 16);
+  d = base2dec (str, 16);
 
 endfunction
 
@@ -61,6 +65,5 @@ endfunction
 %!assert (hex2dec ({"A1", "1A"}), [161; 26])
 
 ## Test input validation
-%!error hex2dec ()
-%!error hex2dec (1)
-%!error hex2dec ("1", 2)
+%!error <Invalid call> hex2dec ()
+%!error <STR must be a string> hex2dec (1)
